/* {{{ Copyright etc. */

/*  avw2ascii.c - convert AVW to raw ASCII text

    Stephen Smith, FMRIB Image Analysis Group

    Copyright (C) 2001 University of Oxford  */

/*  Part of FSL - FMRIB's Software Library
    WWW:      http://www.fmrib.ox.ac.uk/fsl
    Email:    fsl@fmrib.ox.ac.uk
    
    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
    Imaging of the Brain), Department of Clinical Neurology, Oxford
    University, Oxford, UK
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.
    
    This program is distributed in the hope that it will be useful, but in
    order that the University as a charitable foundation protects its
    assets for the benefit of its educational and research purposes, the
    University makes clear that no condition is made or to be implied, nor
    is any warranty given or to be implied, as to the accuracy of FSL, or
    that it will be suitable for any particular purpose or for use under
    any specific conditions.  Furthermore, the University disclaims all
    responsibility for the use which is made of FSL.  See the GNU General
    Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA */

/* }}} */
/* {{{ defines, includes and typedefs */

#include "libss.h"
#include "libavw.h"

void usage(void);

/* }}} */
/* {{{ usage */

void usage(void)
{
  printf("\nUsage: avw2ascii <input> <output>\n\n");
  exit(1);
}

/* }}} */
/* {{{ main */

int main(argc,argv) 
     int argc;
     char **argv;
{
  image_struct im;
  int x,y,z,t;

  /* {{{ process args and read input */

if (argc<3)
     usage();

avw_read(argv[1],&im);

im.t=MAX(im.t,1);

/* }}} */
  /* {{{ process roi and output */

for(t=0;t<im.t;t++)
{
  FILE *ofp;
  char filename[1000];

  sprintf(filename,"%s%05d",argv[2],t);
  ofp=fopen(filename,"w");

  for(z=0;z<im.z;z++)
    {
      for(y=0;y<im.y;y++)
	{
	  for(x=0;x<im.x;x++)
	    {
	      if (im.dt<DT_FLOAT)
		fprintf(ofp,"%d ",(int)  im.i[t*im.z*im.y*im.x + z*im.y*im.x + y*im.x + x]);
	      else
		fprintf(ofp,"%f ",(float)im.i[t*im.z*im.y*im.x + z*im.y*im.x + y*im.x + x]);
	    }
	  fprintf(ofp,"\n");
	}
      fprintf(ofp,"\n");
    }

  fclose(ofp);
}

/* }}} */

  exit(0);
}

/* }}} */
