#{{{ copyright and setup

#   FEAT - FMRIB's Easy Analysis Tool for FMRI
#
#   Stephen Smith, FMRIB Image Analysis Group
#
#   Copyright (C) 1999-2000 University of Oxford
#
#   Part of FSL - FMRIB's Software Library
#   WWW:      http://www.fmrib.ox.ac.uk/fsl
#   Email:    fsl@fmrib.ox.ac.uk
#   
#   Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
#   Imaging of the Brain), Department of Clinical Neurology, Oxford
#   University, Oxford, UK
#   
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or (at
#   your option) any later version.
#   
#   This program is distributed in the hope that it will be useful, but in
#   order that the University as a charitable foundation protects its
#   assets for the benefit of its educational and research purposes, the
#   University makes clear that no condition is made or to be implied, nor
#   is any warranty given or to be implied, as to the accuracy of FSL, or
#   that it will be suitable for any particular purpose or for use under
#   any specific conditions.  Furthermore, the University disclaims all
#   responsibility for the use which is made of FSL.  See the GNU General
#   Public License for more details.
#   
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
#   USA

source [ file dirname [ info script ] ]/fslstart.tcl

set VARS(history) {}

#}}}
#{{{ feat4:renderhighres

proc feat4:renderhighres { w } {
    global PXHOME FSLDIR VARS argc argv PWD entries rendervars

    #{{{ setup main window

toplevel $w

wm title      $w "Colour render high res FEAT stats"
wm iconname   $w "FEAT render"
wm iconbitmap $w @${FSLDIR}/tcl/fmrib.xbm

frame $w.f
pack $w.f -in $w -side top

FSLFileEntry $w.f.featdir \
	-variable entries($w,1) \
	-pattern "*.feat" \
	-directory "~" \
	-label "Select a FEAT directory" \
	-title "Select a FEAT directory" \
	-width 20 \
	-dirasfile "design.fsf" \
	-filterhist VARS(history)

frame $w.f.minmax
set rendervars(zmin) 1
tixControl $w.f.zmin -label "Min" -variable rendervars(zmin) -step 1 -min 0 -selectmode immediate -options { entry.width 4 }
set rendervars(zmax) 15
tixControl $w.f.zmax -label "Max" -variable rendervars(zmax) -step 1 -min 0 -selectmode immediate -options { entry.width 4 }
pack $w.f.zmin $w.f.zmax -in $w.f.minmax -side left -anchor w -padx 5

frame $w.f.talairach
label $w.f.talairach.label -text "Do rendering in Talairach space instead of original high res space"
set rendervars(talairach) 0
checkbutton $w.f.talairach.yn -variable rendervars(talairach)
pack $w.f.talairach.label $w.f.talairach.yn -in $w.f.talairach -side left -anchor w

frame $w.f.keep
label $w.f.keep.label -text "Keep 3D files after generating 2D colour pictures"
set rendervars(keep) 0
checkbutton $w.f.keep.yn -variable rendervars(keep)
pack $w.f.keep.label $w.f.keep.yn -in $w.f.keep -side left -anchor w

pack $w.f.featdir $w.f.minmax $w.f.talairach $w.f.keep -in $w.f -padx 5 -pady 5 -anchor w

#}}}
    #{{{ Button Frame

frame $w.btns
frame $w.btns.b -relief raised -borderwidth 1
    
button $w.apply -command "feat4:renderhighres_proc $w" -text "Go"

button $w.cancel -command "destroy $w" -text "Exit"

pack $w.btns.b -side bottom -fill x -padx 3 -pady 3
pack $w.apply $w.cancel -in $w.btns.b -side left -expand yes -padx 3 -pady 3 -fill y

pack $w.btns -in $w -side bottom -fill x

#}}}
}

#}}}
#{{{ feat4:renderhighres_proc

proc feat4:renderhighres_proc { w } {
    #{{{ setup

global FSLDIR entries rendervars

set FD $entries($w,1)

puts "Processing $FD"

set TAL ""
set KEEP ""
if { $rendervars(talairach) } {
    set TAL -tal
}
if { $rendervars(keep) } {
    set KEEP -keep
}

catch { exec sh -c "${FSLDIR}/bin/renderhighres $FD $rendervars(zmin) $rendervars(zmax) $TAL $KEEP" } errmsg
puts $errmsg

puts "Done"

#}}}
}

#}}}
#{{{ call GUI and wait

wm withdraw .
feat4:renderhighres .r
tkwait window .r

#}}}
