/*  applyxfm4D.cc

    Mark Jenkinson, FMRIB Image Analysis Group

    Copyright (C) 2000 University of Oxford  */

/*  Part of FSL - FMRIB's Software Library
    WWW:      http://www.fmrib.ox.ac.uk/fsl
    Email:    fsl@fmrib.ox.ac.uk
    
    Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
    Imaging of the Brain), Department of Clinical Neurology, Oxford
    University, Oxford, UK
    
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or (at
    your option) any later version.
    
    This program is distributed in the hope that it will be useful, but in
    order that the University as a charitable foundation protects its
    assets for the benefit of its educational and research purposes, the
    University makes clear that no condition is made or to be implied, nor
    is any warranty given or to be implied, as to the accuracy of FSL, or
    that it will be suitable for any particular purpose or for use under
    any specific conditions.  Furthermore, the University disclaims all
    responsibility for the use which is made of FSL.  See the GNU General
    Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
    USA */

#include "newimageall.h"

using namespace NEWIMAGE;

int main(int argc,char *argv[])
{

  Tracer tr("main");
  if (argc<5) { 
    cerr << "Usage: " << argv[0] << " <input volume> <ref volume>"
	 << " <output volume> <transformation matrix file/[dir]> [-singlematrix]]\n"; 
    return -1; 
  }
  
  // NB: a hidden option (-3D) exists (must appear after singlematrix)


  string oname = argv[3], iname = argv[1], 
    transname = argv[4], refname = argv[2];
  bool singlematrix = false;
  if (argc>=6) {
    string option = argv[5];
    if (option == "-singlematrix" )  singlematrix = true;
  }
  bool fourd = true;
  if (argc>=7) {
    string option = argv[6];
    if (option == "-3D" )  fourd = false;
  }

  if (fourd) {
    volume4D<float> invol, outvol;
    volume<float> refvol, dummy;
    volumeinfo vinfo;
    read_volume4D(invol,iname,vinfo);
    invol.setextrapolationmethod(extraslice);

    // old form used a volume number
    //    refvol = invol[atoi(refname.c_str())];  

    read_volume(refvol,refname);

    Matrix affmat(4,4);
    string matname;
    for (int m=invol.mint(); m<=invol.maxt(); m++) {

      if (singlematrix)
	  read_matrix(affmat,transname,invol[0]);
      else
	{
	  matname = transname + "/MAT_0";
	  char nc='0';
	  int n = m;
	  matname += (nc+(n / 100));
	  n -= (n/100)*100;
	  matname += (nc+(n / 10));
	  n -= (n/10)*10;
	  matname += (nc+n);
	  cerr << matname << endl;
	  read_matrix(affmat,matname,invol[0]);
	}
      
      dummy = refvol;
      affine_transform(invol[m],dummy,affmat);
      outvol.addvolume(dummy);
    }
    save_volume4D(outvol,oname,vinfo);

  } else {
    volume<float> invol, outvol;
    volumeinfo vinfo;
    
    read_volume(invol,iname,vinfo);
    read_volume(outvol,refname);
    invol.setextrapolationmethod(extraslice);
    
    Matrix affmat(4,4);
    read_matrix(affmat,transname,invol);
    
    affine_transform(invol,outvol,affmat);
    save_volume(outvol,oname,vinfo);
  }

  return 0;
}




