#

#{{{ setup

#   median - GUI for group median
#
#   Stephen Smith, FMRIB Image Analysis Group
#
#   Copyright (C) 1999-2000 University of Oxford
#
#   Part of FSL - FMRIB's Software Library
#   WWW:      http://www.fmrib.ox.ac.uk/fsl
#   Email:    fsl@fmrib.ox.ac.uk
#   
#   Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
#   Imaging of the Brain), Department of Clinical Neurology, Oxford
#   University, Oxford, UK
#   
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or (at
#   your option) any later version.
#   
#   This program is distributed in the hope that it will be useful, but in
#   order that the University as a charitable foundation protects its
#   assets for the benefit of its educational and research purposes, the
#   University makes clear that no condition is made or to be implied, nor
#   is any warranty given or to be implied, as to the accuracy of FSL, or
#   that it will be suitable for any particular purpose or for use under
#   any specific conditions.  Furthermore, the University disclaims all
#   responsibility for the use which is made of FSL.  See the GNU General
#   Public License for more details.
#   
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
#   USA

if { [ info exists env(FSLDIR) ] } {
    set FSLDIR $env(FSLDIR)
} else {
    set FSLDIR $PXHOME/fsl
}

source ${FSLDIR}/tcl/medxstart.tcl
set auto_path [ linsert $auto_path 0 [ file dirname [ info script ] ] ]

#}}}

proc group_median {Folder Group Popups} {

    global USER FSLDIR

    #{{{ run the median program

MxGetPageProperties $Group GroupProps
set GroupName [keylget GroupProps Name]

set TN [ exec ${FSLDIR}/bin/tmpnam /tmp/med ]

FSLSaveAs $Group AVW ${TN}.hdr true

set thecommand "exec ${FSLDIR}/bin/median $TN ${TN}_out"

puts $thecommand
if {$Popups == 1} {
  ScriptUpdate "Calling $thecommand"
}
set result [catch {eval $thecommand} ErrMsg]

if {$result != 0} {
  puts "$ErrMsg"
}

if {$Popups == 1} {
  CancelScriptUpdate
}

#}}}
    #{{{ read in the output

MxOpenImage $Folder ${TN}_out.hdr Output

MxComputeDisplayRange $Output V Min Max

MxGetImageProperties $Output pl
keylset pl Name "Median of $GroupName"
MxSetImageProperties $Output $pl

exec sh -c "rm -f ${TN}*"

#}}}

    return $Output
}
