#include "options.h"

// $Id: parse.cc,v 1.3 2001/05/11 17:23:48 flitney Exp $

namespace Utilities {

  BaseOption * OptionParser::find_matching_option(const string& optstr)
  {
    for(Options::iterator o = options_.begin();
	o != options_.end();
	++o)
      if((*o)->matches(optstr))
	return *o;

    return 0;
  }

  unsigned int OptionParser::parse_option(const string& optstr,
					  const string& valstr)
    throw(X_AlreadySet, X_UnknownOption, 
	  X_MissingArgument, X_InvalidArgument)
  {
    BaseOption * theOption = 0;

    if((theOption = find_matching_option(optstr)) == 0)
      throw X_UnknownOption(optstr);

    if(theOption->unset()) 
      {
	if(theOption->has_arg())
	  if(valstr.length() > 0) {
	    if(theOption->set_value(valstr))
	      return 2;
	    else
	      throw X_InvalidArgument(optstr, valstr);
	  } else {
	    throw X_MissingArgument(optstr);
	  }
	theOption->set_value(string());
	return 1;
      } 
    else 
      {
	throw X_AlreadySet(optstr);
      }

    throw X_UnknownOption(optstr);
    return 0;
  }

  unsigned int OptionParser::parse_long_option(const string& str)
  {
    string optstr(str);
    string valstr;

    string::size_type pos = 0;
    if((pos = str.find("=", 0)) != string::npos) {
      optstr = str.substr(0, pos);
      valstr = str.substr(pos + 1, str.length() - pos + 1);
    }

    parse_option(optstr, valstr);

    return 1;
  }

  unsigned int OptionParser::parse_command_line(unsigned int argc, 
						char **argv) 
  {
    unsigned int optpos = 1;
    unsigned int valpos = 1;

    while(optpos < argc) {

      unsigned int increments = 0;
      
      string optstr(argv[optpos]), valstr;

      if(optstr[0] != '-')	// End of parsable options
	break;

      if(optstr[1] == '-') {	// Parse a long opt

	increments = parse_long_option(optstr);
	optpos += increments;

      } else {

	valpos = optpos + 1;

	for(unsigned int i = 1; i < optstr.length(); ++i)
	  {
	    string suboptstr = "-" + optstr.substr(i, 1);
	    
	    if(valpos < argc) {
	      valstr = string(argv[valpos]);
	      increments = parse_option(suboptstr, valstr);
	    } else {
	      increments = parse_option(suboptstr, string());
	    }
	    
	    valpos += increments - 1;
	  }
	
	optpos = valpos;
      }
    } 
    return optpos;		// User should process any remaining args
  }

}
