#include <strstream>
#include "filepgm.h"
using namespace std;


/////////////////////////////////////////////////////////////////////
/// CPGMFormat

ZImageBase* ZPGMImage::ReadFile()
{
	if(!IsOpen())
	{
		ZWarning("PGMReader", "%s -- File is not opened!", m_filename.c_str());
		return 0;
	}

	UINT			Width, Height, MaxColor;
	char			MagicNumber[5],line[200];
	PBYTE			pImageBuf;
	bool			bColor;

	char linechar=char(10), lchar;
	m_ImageStream.getline(MagicNumber,4, linechar);
	if(strncmp(MagicNumber, PGM_ASCLL_MAGIC_NUMBER, 2)==0 || 
	   strncmp(MagicNumber, PPM_ASCLL_MAGIC_NUMBER, 2)==0)
	{
		ZWarning("PGMReader", "%s -- ASCII Encoded PGM is not supported!", m_filename.c_str());
		return 0;
	}

	do { 
		m_ImageStream.getline(line,200,linechar); 
	} while(line[0] == '#');

	strstreambuf sbuf(line, 200);
	istream	text(&sbuf);
	text >> Width >> Height;
	m_ImageStream >> MaxColor;
	do { m_ImageStream.get(lchar); }while(lchar != linechar);

	if(Width * Height == 0)
	{
		ZWarning("PGMReader", "%s -- Not a valid PGM File! (image size %d x %d)", m_filename.c_str(), Width, Height);
		return 0;
	}

	ZImageBase* image = 0;
	if(strncmp(MagicNumber, PGM_BINARY_MAGIC_NUMBER, 2) == 0)
	{
		bColor = false;
		image = new ZGrayByteImage(Width, Height);
	}
	else if(strncmp(MagicNumber, PPM_BINARY_MAGIC_NUMBER, 2) == 0)
	{
		bColor = true;
		image = new ZRGBByteImage(Width, Height);
	}
	else
	{
		ZWarning("PGMReader", "%s -- Not a valid PGM File! (Magic number %s)", m_filename.c_str(), MagicNumber);
		return 0;
	}

	pImageBuf = image->GetBuffer();
	if(!Read(pImageBuf, image->MemorySize()))
	{
		ZWarning("PGMReader", "%s -- Error occurs when reading", m_filename.c_str());
		delete image;
		return 0;
	}

	return image;
}

bool ZPGMImage::WriteFile(const ZImageBase& image, bool intensityscale)
{
	if(!IsOpen())
	{
		ZWarning("PGMWriter", "%s -- File is not opened!", m_filename.c_str());
		return false;
	}

	if(!image.IfValid() || image.GetBuffer() == 0)
	{
		ZWarning("PGMWriter", "%s -- Image buffer not available!", m_filename.c_str());
		return false;
	}

	UINT	Width, Height;

	Width = image.Width();
	Height = image.Height(); 

	const ZImageBase* tmpimage = &image;
	ZImage<BYTE>				gimage;
	ZImage< ZRGB<BYTE> >		cgimage;

	if(image.Depth() > 1) image.GotoSlice(0);

	if(m_bPGM && image.BytesPerPixel() > 1)
	{
		if((image.PixFmt() & epixfmtNumericTypeMask) != epixfmtChar || intensityscale) 
			image.CopyPixelsTo(gimage, 0, 255);
		else
			image.CopyPixelsTo(gimage);

		tmpimage = &gimage;
	}
	else if(!m_bPGM && image.BytesPerPixel() != 3)
	{
		if((image.PixFmt() & epixfmtNumericTypeMask) != epixfmtChar || intensityscale) 
			image.CopyPixelsTo(cgimage, 0, 255);
		else 
			image.CopyPixelsTo(cgimage); 

		tmpimage = &cgimage;
	}

	if(!m_bPGM)
		m_ImageStream << PPM_BINARY_MAGIC_NUMBER << '\n';
	else
		m_ImageStream << PGM_BINARY_MAGIC_NUMBER << '\n';

	m_ImageStream << '#' << ' ' << PGM_COMMENTS << '\n';
	m_ImageStream << Width << ' ' << Height << '\n' << MAX_GRAY_LEVEL << '\n';

	WriteImage(*tmpimage, m_ImageStream);

	if(Fail())
	{
		ZWarning("PGMWriter", "%s -- Error occurs when writing!", m_filename.c_str());
		return false;
	}
	return true;
}
