#

# Copyright (C) 1998 John O'Doherty
# Dept. of Exp. Psy., Oxford. E-mail:john.odoherty@psy.ox.ac.uk
# Plus a few alterations, Steve Smith

#   Part of FSL - FMRIB's Software Library
#   WWW:      http://www.fmrib.ox.ac.uk/fsl
#   Email:    fsl@fmrib.ox.ac.uk
#   
#   Developed at FMRIB (Oxford Centre for Functional Magnetic Resonance
#   Imaging of the Brain), Department of Clinical Neurology, Oxford
#   University, Oxford, UK
#   
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or (at
#   your option) any later version.
#   
#   This program is distributed in the hope that it will be useful, but in
#   order that the University as a charitable foundation protects its
#   assets for the benefit of its educational and research purposes, the
#   University makes clear that no condition is made or to be implied, nor
#   is any warranty given or to be implied, as to the accuracy of FSL, or
#   that it will be suitable for any particular purpose or for use under
#   any specific conditions.  Furthermore, the University disclaims all
#   responsibility for the use which is made of FSL.  See the GNU General
#   Public License for more details.
#   
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
#   USA

if { [ info exists env(FSLDIR) ] } {
    set FSLDIR $env(FSLDIR)
} else {
    set FSLDIR $PXHOME/fsl
}

source ${FSLDIR}/tcl/medxstart.tcl
set auto_path [ linsert $auto_path 0 [ file dirname [ info script ] ] ]

set on "onvol"
set off "offvols"
set colon ":"
set imagelist ""
set orderon 0
set orderoff 0

#enter number of files
InputFromWidget "Serial T-test" 6 "Initial offset" initialoffset 6 "Size of ON period" onsize 6 "Size of OFF period" offsize 6 "# images for comparison from ON period" nofromon 6  "offset in OFF period" offset 6 "# images for comparison from OFF period" nofromoff 6 

set reply [YesNoWidget "Start with ON or OFF groups?"  ON OFF]
if {$reply==0} {
set orderoff $onsize
set orderon  $offsize
}

MxGetCurrentFolder folder
MxGetCurrentGroup group
MxGetPagesFromGroup $Group Pages
set totnum 0
foreach Page $Pages {
incr totnum 1
}

set cyclen  [expr $onsize+$offsize]
set channel [open "/tmp/${USER}stt.pdm" "w"] 

puts $channel "%!VEST-ParadigmFile"
puts $channel "#groups"

#identify on groups
for {set i 1} {$i <= [expr ($onsize - $nofromon + 1)]} {incr i 1} {
puts $channel $on$i
}
#add off group
puts $channel "offvols"
puts $channel "All"

#add group colours
puts $channel "# group colours"
for {set i 1} {$i <= [expr ($onsize - $nofromon + 1)]} {incr i 1} {
puts $channel "$on$i red"
}
puts $channel "offvols blue"
puts $channel "All    black"

#set out time points
puts $channel "# time points"

for {set n $initialoffset} {$n < $totnum} {incr n $cyclen} {

     for {set groupno 1} {$groupno <= [expr ($onsize - $nofromon + 1)]} {incr groupno 1} {
       set on_start [expr $groupno + $n + $orderon]
       set on_finish [expr $on_start + $nofromon - 1]
       if { $on_finish <= $totnum } {
         set outon "$on_start$colon$on_finish     onvol$groupno"
         #Add ALL to non-overlapping groups
         if ([expr $on_start % $nofromon]==1) {
         append outon "    All"
         }
         puts $channel  $outon
       }       
     }
 set off_start [expr $n + $onsize + $offset-$orderoff + 1]
 set off_finish [expr $off_start + $nofromoff - 1]
 if { $on_finish <= $totnum } {
   set outoff "$off_start$colon$off_finish   offvols       All"
   puts $channel $outoff    
 }
 }
       
close $channel

#load the new paradigm file
MxApplyParadigmGrouping $group "/tmp/${USER}stt.pdm"  resultgroups
MxGetPageByName $folder $off offp

#then go through and perform serial t-tests
for {set i 1} {$i <= [expr ($onsize - $nofromon + 1)]} {incr i 1} {
MxGetPageByName $folder $on$i onp 
MxBetweenGrpStatistics $onp $offp U I0 I1 I2 I3 I4
append imagelist $I3 " "
}

MxGroupImages $imagelist I "Serial T-Test:z-maps" I5
